@@ -5,11 +5,6 @@ from importlib.machinery import SourceFileLoader
 
 
 def main():
-    # Show help even if there is no fsetup.py.
-    if len(sys.argv) == 1:
-        fbrp.main()
-        return
-
     # Default the entrypoint file to the fsetup.py in the current directory.
     fsetup_path = os.path.abspath("fsetup.py")
     # The user may specify another entrypoint with:
@@ -18,9 +13,10 @@ def main():
         fsetup_path = os.path.abspath(sys.argv[2])
         sys.argv = sys.argv[:1] + sys.argv[3:]
 
-    # Ensure the entrypoint file exists.
+    # Show help even if there is no fsetup.py.
     if not os.path.exists(fsetup_path):
-        fbrp.util.fail(f"No fsetup.py file found.")
+        fbrp.main()
+        return
 
     # Run the entrypoint file.
     SourceFileLoader("fsetup", fsetup_path).load_module()
